from django_solar import AEventManager, MailTemplate
from django_solar.models import Mail
from datetime import datetime


class EventManager(AEventManager):

    def event_something(self):
        Mail.objects.create(
            mail='test@exemple.com',  #  Receiver
            send_at=datetime.now(),  #  Datetime send
            html=MailTemplate.get(key='test'),  #  HTML of email
            subject="Test Django Solar",  #  Subject of email
            event="something"
        )



# Generated by Django 3.1.1 on 2020-09-18 02:22

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Mail',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_send', models.BooleanField(default=False)),
                ('send_at', models.DateTimeField(default=datetime.datetime.now)),
                ('event', models.CharField(default='', max_length=100)),
                ('mail', models.EmailField(default=None, max_length=254, null=True)),
                ('subject', models.CharField(default='', max_length=100)),
                ('html', models.TextField(default=None)),
                ('text', models.TextField(default='')),
                ('from_mail', models.CharField(default='hello@snoweb.fr', max_length=100)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



from django.template.loader import get_template


class AEventManager(object):

    def get_event_functions(self):
        functions = []
        for func in dir(self):
            if 'event_' in func:
                functions.append(getattr(self, func, None))
        return functions


class MailTemplate(object):

    @staticmethod
    def get(key, context=None):
        tpl = get_template('django_solar/mail_templates/%s.html' % key)
        return tpl.render(context)
